==> kexchange-0.1.tar.gz: kexchange-0.1/kexchange/kextable.h <==
/***************************************************************************
                          kextable.h  -  description
                             -------------------
    begin                : Tue Mar 5 2002
    copyright            : (C) 2002 by Tero Favorin
    email                : tero@favorin.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KEXTABLE_H
#define KEXTABLE_H

#include <qwidget.h>
/**
  *@author Tero Favorin
  */
class QTable;
class QLabel;
class KExDataSource;
class KExSource;
class KComboBox;
class KLocale;

class KExTable : public QWidget {
Q_OBJECT
public: 
	KExTable(QWidget * parent=0, const char * name=0, WFlags f=0);
	~KExTable();
	void setOptions(KExDataSource *d, bool e);
	QString getBase();
	void setBase(QString b);
public slots:
	void updateBase(int);
private:
	KExDataSource *data;
	KLocale *locale;

	QStringList list;
	QLabel *base;
	bool oldeuro;
	KComboBox *baseCombo;
	QTable *table;
	KExSource *source;

};

#endif

==> kexchange-0.2.tar.gz: kexchange-0.2/kexchange/kextable.h <==
/***************************************************************************
                          kextable.h  -  description
                             -------------------
    begin                : Tue Mar 5 2002
    copyright            : (C) 2002 by Tero Favorin
    email                : tero@favorin.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KEXTABLE_H
#define KEXTABLE_H

#include <qwidget.h>
#include <qstringlist.h>
/**
  *@author Tero Favorin
  */
class QTable;
class QLabel;
class	QRadioButton;
class KExDataSource;
class KExSource;
class KComboBox;

class KExTable : public QWidget {
Q_OBJECT
public: 
	KExTable(QWidget * parent=0, const char * name=0, WFlags f=0);
	~KExTable();
	void setOptions(KExDataSource *d, bool e);
	QString getBase();
	void setBase(QString b);
	bool getUnitBase();
	void setUnitBase(bool);
public slots:
	void updateBase(int);
	void unitToggle ( bool );
private:
	KExDataSource *data;
	QStringList list;
	QLabel *base;
	bool oldeuro;
	KComboBox *baseCombo;
	QRadioButton *unitBase;
	QRadioButton *baseUnit;
	QTable *table;
	KExSource *source;

};

#endif
